@@ -1,9 +1,10 @@
-__version__ = '0.4.2'
+__version__ = '0.6'
 __author__ = 'Neil Freeman'
 __license__ = 'all rights reserved'
-__all__ = ['api', 'creation', 'helpers', 'tools']
+__all__ = ['api', 'confighelper', 'creation', 'helpers', 'tools']
 
 from . import api
 from . import helpers
+from . import confighelper
 from .creation import add_default_args, defaults, setup_args
 from . import tools
