@@ -11,11 +11,10 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from HTMLParser import HTMLParser
-import yaml
-import json
-
+try:
+    from html.parser import HTMLParser
+except ImportError:
+    from html.parser import HTMLParser
 
 def has_url(status):
     return has_entity(status, 'urls')
@@ -46,7 +45,7 @@ def has_entity(status, entitykey):
 
 def has_entities(status):
     try:
-        if len([i for v in status.entities.values() for i in v]) > 0:
+        if len([i for v in list(status.entities.values()) for i in v]) > 0:
             return True
 
     except (AttributeError, KeyError):
@@ -63,15 +62,6 @@ def format_text(text):
     return HTMLParser().unescape(text).replace('\n', ' ').strip()
 
 
-def config_parse(file_path):
-    with open(file_path, 'r') as f:
-        if file_path[-4:] == 'yaml':
-            return yaml.load(f.read())
-
-        elif file_path[-4:] == 'json':
-            return json.load(f.read())
-
-
 def remove_entity(status, entitytype):
     '''Use indices to remove given entity type from status text'''
     return remove_entities(status, [entitytype])
@@ -86,7 +76,7 @@ def remove_entities(status, entitylist):
         entities = status.get('entities', dict())
         text = status['text']
 
-    indices = [ent['indices'] for etype, entval in entities.items() for ent in entval if etype in entitylist]
+    indices = [ent['indices'] for etype, entval in list(entities.items()) for ent in entval if etype in entitylist]
     indices.sort(key=lambda x: x[0], reverse=True)
 
     for start, end in indices:
